package ACL2::Proceso::AbandonarMetaPrincipal;
use base ACL2::Proceso;

=head1 NAME

ACL2::Proceso::AbandonarMetaPrincipal - se abandona la meta principal para pasar despuE<eacute>s a inducciE<oacute>n

=head1 FUNCTIONS

=cut

#
#    Clase AbandonarMetaPrincipal: se abandona la meta principal para
#    pasar después a inducción (:OTF-FLAG debe ser NIL)
#
#    Copyright (C) 2006-2008 Antonio García Domínguez
#    $Id$
#
#    This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#

use strict;
use warnings;
use ACL2::Orden;
use ACL2::Proceso::Fabrica;

BEGIN {
    ACL2::Proceso::Fabrica->registrar
	(
	 __PACKAGE__,
	 sub {
	     return ACL2::Proceso::AbandonarMetaPrincipal->_identificar(@_);
	 }
	 );
  }

sub escribir_xml_cabecera {
    my ($this, $writer) = @_;
    $writer->startTag(ACL2::Tags::ABANDONOTF_TAG);
    ACL2::Orden->salida_parrafos($writer, $this->{salida});
}

sub escribir_xml_final {
    my ($this, $writer) = @_;
    $writer->endTag(ACL2::Tags::ABANDONOTF_TAG);
}

sub _identificar
{
    my ($paquete, $salida) = @_;
    my %res      = ();

    $salida =~ /^\s*(?-x:Normally we would attempt to prove .*?)
	(?-x: by induction. However, we prefer in this instance)
	(?-x: .*? reassign the name .*? to the original conjecture\.)/ox 
	or return undef;

    $res{salida} = substr $salida, $-[0], $+[0] - $-[0];

    return \%res;
}

1;
